// FrameBuffer.h

#ifndef FRAME_BUFFER_H
#define FRAME_BUFFER_H

#include <string.h>

// Provides convenient access to a frame buffer.
class FrameBuffer {
public:
	FrameBuffer(uint8* bits, int32 width, int32 height, int32 bpr)
	{
		fBits = bits;
		fWidth = width;
		fHeight = height;
		fBPR = bpr;
	}

	uint8* GetBits() const
	{
		return fBits;
	}

	inline int32 Width() const
	{
		return fWidth;
	}

	inline int32 Height() const
	{
		return fHeight;
	}

	inline int32 BPR() const
	{
		return fBPR;
	}

	inline void WritePixel(int x, int y, int c)
	{
		fBits[y * fBPR + x] = c;
	}
	
	inline int ReadPixel(int x, int y) const
	{
		return fBits[y * fBPR + x];
	}
	
	inline void ClearScreen(int col = 0)
	{
		uint8* line = fBits;
		for (int y = 0; y < fHeight; y++, line += fBPR)
			memset(line, col, fWidth);
	}

private:
	uint8*	fBits;
	int32	fWidth;
	int32	fHeight;
	int32	fBPR;
};

#endif	// FRAME_BUFFER_H
